



python C:\ci\containers\00001gbdr8d\tmp\build\80754af9\rsync-recipes\gdal-split-3.0.2-vc_14-cxx_compiler_vs2017-c_compiler_vs2017-geos_3.8.0-on-winbuilder/run_test.py
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
